@@ -199,8 +199,8 @@ EMMA <- function(
   if(missing(Vqn) == TRUE) {
     
     ## calculate row-wise min and max values
-    Vqr.min <- matrixStats::rowMins(x = Vqr)
-    Vqr.max <- matrixStats::rowMaxs(x = Vqr)
+    Vqr.min <- apply(X = Vqr, MARGIN = 1, FUN = min)
+    Vqr.max <- apply(X = Vqr, MARGIN = 1, FUN = max)
     
     ## calculate Vqn
     Vqn <- (Vqr - Vqr.min) / (Vqr.max - Vqr.min)
@@ -213,7 +213,7 @@ EMMA <- function(
   ## get eigenvector scores as non-negative least squares estimate
   Mq <- t(apply(W, MARGIN = 1, FUN = function(row) {
     
-    limSolve::nnls(t(Vqn), as.vector(t(row)))$X
+    nnls::nnls(t(Vqn), as.vector(t(row)))$x
   }))
   
   ## modelled values matrix
@@ -261,7 +261,7 @@ EMMA <- function(
   Xm  <- Xm / rowSums(Xm) * c
   
   ## evaluate absolute error and explained variances
-  Mqs.var <- colVars(x = Mqs)
+  Mqs.var <- apply(X = Mqs, MARGIN = 2, FUN = var)
   Mqs.var <- Mqs.var / sum(Mqs.var) * 100 # explained scores variance
   Em <- rowMeans(x = abs(X - Xm))         # absolute row-wise model error
   En <- rowMeans(x = abs(X - Xm))         # absolute column-wise model error
@@ -277,8 +277,8 @@ EMMA <- function(
   ## create auxiliary x-unit and index variable, calculate index
   x.unit <- 1:ncol(X)
   ind <- numeric(q)
+  
   for (i in 1:q) {
-    
     ind[i] <- x.unit[Vqsn[i,] == max(Vqsn[i,])]
   }
   ind.sort <- seq(1, nrow(Vqsn))[order(ind)]
@@ -294,8 +294,9 @@ EMMA <- function(
   
   ## determine mode class for all end-member loadings
   modes <- numeric(q)
-  for(i in 1:q) {modes[i] <- classunits[Vqsn[i,1:ncol(
-    Vqsn)] == max(Vqsn[i,1:ncol(Vqsn)])]}
+  for(i in 1:q) {
+    modes[i] <- classunits[Vqsn[i,1:ncol(Vqsn)] == max(Vqsn[i,1:ncol(Vqsn)])]
+  }
  
   ## optionally, plot end-member loadings and scores
   if(plot == TRUE) {
